@@ -194,7 +194,7 @@ pub fn tile(
     builder: &mut ModelBuilder,
     invocation: &ResolvedInvocation,
 ) -> TractResult<TVec<OutletId>> {
-    let multipliers: TVec<usize> = invocation.named_arg_as(builder, "repeat")?;
+    let multipliers: TVec<usize> = invocation.named_arg_as(builder, "repeats")?;
     let wire = tvec!(invocation.named_arg_as(builder, "input")?);
     Ok(builder.wire(ops::array::Tile { multipliers }, &wire)?)
 }
@@ -562,3 +562,16 @@ pub fn select(
 
     builder.wire(ops::logic::Iff {}, &inputs)
 }
+
+/*
+ * fragment prelu( x: tensor<scalar>, alpha: tensor<scalar> )-> ( y: tensor<scalar> )
+ */
+
+pub fn prelu(
+    builder: &mut ModelBuilder,
+    invocation: &ResolvedInvocation,
+) -> TractResult<TVec<OutletId>> {
+    let x = invocation.named_arg_as(builder, "x")?;
+    let alpha = invocation.named_arg_as(builder, "alpha")?;
+    builder.wire(ops::nn::prelu(alpha) , &[x])
+}
