@@ -71,7 +71,7 @@ pub fn tile(
     op: &ops::array::Tile,
 ) -> TractResult<Option<Arc<RValue>>> {
     let wire = ast.mapping[&node.inputs[0]].clone();
-    Ok(Some(invocation("tile", &[wire], &[("repeat", ints(&op.multipliers))])))
+    Ok(Some(invocation("tile", &[wire], &[("repeats", ints(&op.multipliers))])))
 }
 
 pub fn pad(
@@ -523,3 +523,16 @@ pub fn select(
         &[],
     )))
 }
+
+pub fn prelu(
+    ast: &mut IntoAst,
+    node: &TypedNode,
+) -> TractResult<Option<Arc<RValue>>> {
+    let op = node.op_as::<ops::element_wise::ElementWiseOp>().context("Wrong op")?;
+    let op = op.0.downcast_ref::<ops::nn::Prelu>().context("Wrong op")?;
+    Ok(Some(invocation(
+        "prelu",
+        &node.inputs.iter().map(|o| ast.mapping[o].clone()).collect::<TVec<_>>(),
+        &[("alpha", RValue::Literal(op.alpha.into()))],
+    )))
+}
